@@ -7,11 +7,11 @@
 #pragma once
 
 #include <memory>
-#include <vector>
 
-#include <vinecopulib/misc/tools_eigen.hpp>
+#include <Eigen/Dense>
 #include <vinecopulib/bicop/family.hpp>
 
+
 namespace vinecopulib {
 //! @brief An abstract class for bivariate copula families
 //!
@@ -42,14 +42,18 @@ protected:
 
     virtual Eigen::MatrixXd get_parameters() const = 0;
 
+    virtual Eigen::MatrixXd get_parameters_lower_bounds() const = 0;
+
+    virtual Eigen::MatrixXd get_parameters_upper_bounds() const = 0;
+
     virtual void set_parameters(const Eigen::MatrixXd &parameters) = 0;
 
     virtual void flip() = 0;
 
     // Virtual methods
     virtual void fit(const Eigen::Matrix<double, Eigen::Dynamic, 2> &data,
-                     std::string method, 
-                     double mult, 
+                     std::string method,
+                     double mult,
                      const Eigen::VectorXd& weights) = 0;
 
     virtual double calculate_npars() = 0;
@@ -58,6 +62,9 @@ protected:
 
     Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
 
+    double loglik(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u,
+              const Eigen::VectorXd weights = Eigen::VectorXd());
+
     virtual Eigen::VectorXd pdf_raw(
         const Eigen::Matrix<double, Eigen::Dynamic, 2> &u) = 0;
 
@@ -77,6 +84,7 @@ protected:
         const Eigen::Matrix<double, Eigen::Dynamic, 2> &u) = 0;
 
     virtual Eigen::MatrixXd tau_to_parameters(const double &tau) = 0;
+    Eigen::MatrixXd no_tau_to_parameters(const double &);
 
     // Misc methods
     Eigen::VectorXd hinv1_num(
@@ -93,7 +101,6 @@ protected:
 //! A shared pointer to an object of class AbstracBicop.
 typedef std::shared_ptr <AbstractBicop> BicopPtr;
 
-Eigen::VectorXd no_tau_to_parameters(const double &);
 }
 
 #include <vinecopulib/bicop/implementation/abstract.ipp>
