@@ -7,7 +7,6 @@
 #pragma once
 
 #include <boost/math/distributions.hpp>
-#include <random>
 #include <vinecopulib/misc/tools_eigen.hpp>
 
 namespace vinecopulib {
@@ -15,7 +14,7 @@ namespace vinecopulib {
 namespace tools_stats {
 
 
-//! Density function of the Standard normal distribution
+//! @brief Density function of the Standard normal distribution.
 //!
 //! @param x evaluation points.
 //!
@@ -27,7 +26,7 @@ inline Eigen::MatrixXd dnorm(const Eigen::MatrixXd &x)
     return tools_eigen::unaryExpr_or_nan(x, f);
 }
 
-//! Distribution function of the Standard normal distribution
+//! @brief Distribution function of the Standard normal distribution.
 //!
 //! @param x evaluation points.
 //!
@@ -39,7 +38,7 @@ inline Eigen::MatrixXd pnorm(const Eigen::MatrixXd &x)
     return tools_eigen::unaryExpr_or_nan(x, f);
 }
 
-//! Quantile function of the Standard normal distribution
+//! @brief Quantile function of the Standard normal distribution.
 //!
 //! @param x evaluation points.
 //!
@@ -51,7 +50,7 @@ inline Eigen::MatrixXd qnorm(const Eigen::MatrixXd &x)
     return tools_eigen::unaryExpr_or_nan(x, f);
 }
 
-//! Density function of the Student t distribution
+//! @brief Density function of the Student t distribution.
 //!
 //! @param x evaluation points.
 //! @param nu degrees of freedom parameter.
@@ -64,7 +63,7 @@ inline Eigen::MatrixXd dt(const Eigen::MatrixXd &x, double nu)
     return tools_eigen::unaryExpr_or_nan(x, f);
 }
 
-//! Distribution function of the Student t distribution
+//! @brief Distribution function of the Student t distribution.
 //!
 //! @param x evaluation points.
 //! @param nu degrees of freedom parameter.
@@ -77,7 +76,7 @@ inline Eigen::MatrixXd pt(const Eigen::MatrixXd &x, double nu)
     return tools_eigen::unaryExpr_or_nan(x, f);
 }
 
-//! Quantile function of the Student t distribution
+//! @brief Quantile function of the Student t distribution.
 //!
 //! @param x evaluation points.
 //! @param nu degrees of freedom parameter.
@@ -93,6 +92,9 @@ inline Eigen::MatrixXd qt(const Eigen::MatrixXd &x, double nu)
 Eigen::MatrixXd simulate_uniform(const size_t& n, const size_t& d,
                                  std::vector<int> seeds = std::vector<int>());
 
+Eigen::MatrixXd simulate_uniform(const size_t& n, const size_t& d, bool qrng,
+                                  std::vector<int> seeds = std::vector<int>());
+
 Eigen::VectorXd to_pseudo_obs_1d(Eigen::VectorXd x,
                                  std::string ties_method = "average");
 
