@@ -1,4 +1,4 @@
-// Copyright © 2018 Thomas Nagler and Thibault Vatter
+// Copyright © 2016-2019 Thomas Nagler and Thibault Vatter
 //
 // This file is part of the vinecopulib library and licensed under the terms of
 // the MIT license. For a copy, see the LICENSE file in the root directory of
@@ -7,9 +7,18 @@
 #pragma once
 
 #include <limits>
-
 #include <vinecopulib/bicop/fit_controls.hpp>
 
+#if defined(__GNUC__) || defined(__clang__)
+#define DEPRECATED __attribute__((deprecated))
+#elif defined(_MSC_VER)
+#define DEPRECATED __declspec(deprecated)
+#else
+#pragma message("WARNING: You need to implement DEPRECATED for this compiler")
+#define DEPRECATED
+#endif
+
+
 namespace vinecopulib {
 //! @brief A class for controlling fit of bivariate copula models.
 //!
@@ -23,29 +32,30 @@ public:
                        std::string parametric_method = "mle",
                        std::string nonparametric_method = "quadratic",
                        double nonparametric_mult = 1.0,
-                       size_t truncation_level = std::numeric_limits<size_t>::max(),
+                       size_t trunc_lvl = std::numeric_limits<size_t>::max(),
                        std::string tree_criterion = "tau",
                        double threshold = 0.0,
                        std::string selection_criterion = "bic",
                        const Eigen::VectorXd& weights = Eigen::VectorXd(),
                        double psi0 = 0.9,
                        bool preselect_families = true,
-                       bool select_truncation_level = false,
+                       bool select_trunc_lvl = false,
                        bool select_threshold = false,
                        bool show_trace = false,
                        size_t num_threads = 1);
 
     FitControlsVinecop(const FitControlsBicop &controls,
-                       size_t truncation_level = std::numeric_limits<size_t>::max(),
+                       size_t trunc_lvl = std::numeric_limits<size_t>::max(),
                        std::string tree_criterion = "tau",
                        double threshold = 0.0,
-                       bool select_truncation_level = false,
+                       bool select_trunc_lvl = false,
                        bool select_threshold = false,
                        bool show_trace = false,
                        size_t num_threads = 1);
 
     // Getters
-    size_t get_truncation_level() const;
+    DEPRECATED size_t get_truncation_level() const;
+    size_t get_trunc_lvl() const;
 
     std::string get_tree_criterion() const;
 
@@ -53,7 +63,8 @@ public:
 
     bool get_show_trace() const;
 
-    bool get_select_truncation_level() const;
+    DEPRECATED bool get_select_truncation_level() const;
+    bool get_select_trunc_lvl() const;
 
     bool get_select_threshold() const;
 
@@ -62,7 +73,8 @@ public:
     FitControlsBicop get_fit_controls_bicop() const;
 
     // Setters
-    void set_truncation_level(size_t truncation_level);
+    DEPRECATED void set_truncation_level(size_t trunc_lvl);
+    void set_trunc_lvl(size_t trunc_lvl);
 
     void set_tree_criterion(std::string tree_criterion);
 
@@ -70,18 +82,19 @@ public:
 
     void set_show_trace(bool show_trace);
 
-    void set_select_truncation_level(bool select_truncation_level);
+    DEPRECATED void set_select_truncation_level(bool select_trunc_lvl);
+    void set_select_trunc_lvl(bool select_trunc_lvl);
 
     void set_select_threshold(bool select_threshold);
 
     void set_fit_controls_bicop(FitControlsBicop controls);
 
 private:
-    size_t truncation_level_;
+    size_t trunc_lvl_;
     std::string tree_criterion_;
     double threshold_;
     bool show_trace_;
-    bool select_truncation_level_;
+    bool select_trunc_lvl_;
     bool select_threshold_;
 
     void check_tree_criterion(std::string tree_criterion);
